@@ -164,6 +164,7 @@ class Assistant(AssistantBase):
     user_abilities: Optional[List[Any]] = None
     mcp_servers: List[MCPServerDetails] = Field(default_factory=list)
     assistant_ids: List[str] = Field(default_factory=list)
+    version_count: Optional[int] = None
 
 
 class AssistantRequestBase(AssistantBase):
@@ -205,6 +206,26 @@ class AssistantUpdateRequest(AssistantRequestBase):
     pass
 
 
+class AssistantVersion(BaseModel):
+    """Immutable snapshot of assistant configuration for a specific version."""
+
+    model_config = ConfigDict(extra="ignore", use_enum_values=True)
+
+    version_number: int
+    created_date: datetime
+    created_by: Optional[User] = None
+    change_notes: Optional[str] = None
+    description: Optional[str] = None
+    system_prompt: str
+    llm_model_type: Optional[str] = None
+    temperature: Optional[float] = None
+    top_p: Optional[float] = None
+    context: List[Context] = Field(default_factory=list)
+    toolkits: List[ToolKitDetails] = Field(default_factory=list)
+    mcp_servers: List[MCPServerDetails] = Field(default_factory=list)
+    assistant_ids: List[str] = Field(default_factory=list)
+
+
 class ChatRole(str, Enum):
     """Enum for chat message roles."""
 
